@@ -9,10 +9,6 @@ describe 'watcher' do
         { :purge_config => false }
       end
 
-      it 'contains the logging class' do
-        is_expected.to contain_class('watcher::logging')
-      end
-
       it 'contains the db class' do
         is_expected.to contain_class('watcher::db')
       end
@@ -193,7 +189,7 @@ describe 'watcher' do
       end
     end
 
-    context 'with overriden amqp parameters' do
+    context 'with overridden amqp parameters' do
       let :params do
         { :default_transport_url => 'amqp://amqp_user:password@localhost:5672',
           :amqp_idle_timeout     => '60',
@@ -217,55 +213,6 @@ describe 'watcher' do
         is_expected.to contain_watcher_config('oslo_messaging_amqp/password').with_value('password')
       end
     end
-
-    context 'with zmq default parameters' do
-      it 'configures zmq' do
-        is_expected.to contain_watcher_config('DEFAULT/rpc_cast_timeout').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('DEFAULT/rpc_poll_timeout').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('DEFAULT/rpc_zmq_bind_address').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('DEFAULT/rpc_zmq_bind_port_retries').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('DEFAULT/rpc_zmq_concurrency').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('DEFAULT/rpc_zmq_contexts').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('DEFAULT/rpc_zmq_host').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('DEFAULT/rpc_zmq_ipc_dir').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('DEFAULT/rpc_zmq_matchmaker').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('DEFAULT/rpc_zmq_max_port').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('DEFAULT/rpc_zmq_min_port').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('DEFAULT/rpc_zmq_topic_backlog').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('DEFAULT/use_pub_sub').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('DEFAULT/zmq_target_expire').with_value('<SERVICE DEFAULT>')
-      end
-    end
-
-    context 'with overriden zmq parameters' do
-      let :params do
-        { :default_transport_url     => 'zmq://zmq_user:password@localhost:5555',
-          :rpc_zmq_min_port          => '49200',
-          :rpc_zmq_max_port          => '65000',
-          :rpc_zmq_bind_port_retries => '120',
-          :rpc_zmq_contexts          => '2',
-          :rpc_zmq_host              => 'localhost',
-        }
-      end
-
-      it 'configures zmq' do
-        is_expected.to contain_watcher_config('DEFAULT/transport_url').with_value('zmq://zmq_user:password@localhost:5555')
-        is_expected.to contain_watcher_config('DEFAULT/rpc_cast_timeout').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('DEFAULT/rpc_poll_timeout').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('DEFAULT/rpc_zmq_bind_address').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('DEFAULT/rpc_zmq_bind_port_retries').with_value('120')
-        is_expected.to contain_watcher_config('DEFAULT/rpc_zmq_concurrency').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('DEFAULT/rpc_zmq_contexts').with_value('2')
-        is_expected.to contain_watcher_config('DEFAULT/rpc_zmq_host').with_value('localhost')
-        is_expected.to contain_watcher_config('DEFAULT/rpc_zmq_ipc_dir').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('DEFAULT/rpc_zmq_matchmaker').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('DEFAULT/rpc_zmq_max_port').with_value('65000')
-        is_expected.to contain_watcher_config('DEFAULT/rpc_zmq_min_port').with_value('49200')
-        is_expected.to contain_watcher_config('DEFAULT/rpc_zmq_topic_backlog').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('DEFAULT/use_pub_sub').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('DEFAULT/zmq_target_expire').with_value('<SERVICE DEFAULT>')
-      end
-    end
   end
 
   on_supported_os({
